You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@shardingsphere.apache.org by me...@apache.org on 2021/05/14 11:00:24 UTC

[shardingsphere] branch master updated: Rename GovernanceCenter to RegistryCenter (#10336)

This is an automated email from the ASF dual-hosted git repository.

menghaoran pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/shardingsphere.git


The following commit(s) were added to refs/heads/master by this push:
     new 8e2fd76  Rename GovernanceCenter to RegistryCenter (#10336)
8e2fd76 is described below

commit 8e2fd767ba333a0dc013bad81e4c88076760d5b1
Author: Liang Zhang <te...@163.com>
AuthorDate: Fri May 14 18:59:36 2021 +0800

    Rename GovernanceCenter to RegistryCenter (#10336)
    
    * Update javadoc
    
    * Rename YamlRegistryCenterConfiguration
    
    * Rename RegistryCenterConfigurationYamlSwapper
    
    * Rename YamlGovernanceConfigurationSwapperUtil
    
    * Rename GovernanceCenter to RegistryCenter
---
 .../GovernanceRepositoryConfigurationUtil.java     | 27 ++++------------------
 .../repository/RegistryCenterRepositoryFacade.java |  8 +++----
 .../yaml/config/YamlGovernanceConfiguration.java   |  2 +-
 ...n.java => YamlRegistryCenterConfiguration.java} |  4 ++--
 .../GovernanceConfigurationYamlSwapper.java        |  6 ++---
 ...=> RegistryCenterConfigurationYamlSwapper.java} | 12 +++++-----
 .../GovernanceConfigurationYamlSwapperTest.java    |  6 ++---
 ...RegistryCenterConfigurationYamlSwapperTest.java | 18 +++++++--------
 .../repository/api/RegistryCenterRepository.java   |  8 +++----
 ...lGovernanceShardingSphereDataSourceFactory.java |  6 ++---
 ...=> YamlGovernanceConfigurationSwapperUtil.java} | 10 ++++----
 ...amlGovernanceConfigurationSwapperUtilTest.java} | 12 +++++-----
 .../ShardingSphereGovernanceAutoConfiguration.java |  4 ++--
 .../additional-spring-configuration-metadata.json  |  3 +--
 ...istryCenterConfigurationBeanDefinitionTag.java} |  4 ++--
 .../handler/GovernanceNamespaceHandler.java        |  6 ++---
 ...ryCenterConfigurationBeanDefinitionParser.java} | 12 +++++-----
 .../swapper/YamlProxyConfigurationSwapperTest.java |  4 ++--
 .../yaml/ServerConfigurationYamlSwapperTest.java   | 10 ++++----
 19 files changed, 72 insertions(+), 90 deletions(-)

diff --git a/examples/shardingsphere-jdbc-example/governance-example/governance-raw-jdbc-example/src/main/java/org/apache/shardingsphere/example/governance/raw/jdbc/config/GovernanceRepositoryConfigurationUtil.java b/examples/shardingsphere-jdbc-example/governance-example/governance-raw-jdbc-example/src/main/java/org/apache/shardingsphere/example/governance/raw/jdbc/config/GovernanceRepositoryConfigurationUtil.java
index 6ef1d4e..dad5261 100644
--- a/examples/shardingsphere-jdbc-example/governance-example/governance-raw-jdbc-example/src/main/java/org/apache/shardingsphere/example/governance/raw/jdbc/config/GovernanceRepositoryConfigurationUtil.java
+++ b/examples/shardingsphere-jdbc-example/governance-example/governance-raw-jdbc-example/src/main/java/org/apache/shardingsphere/example/governance/raw/jdbc/config/GovernanceRepositoryConfigurationUtil.java
@@ -28,33 +28,16 @@ public final class GovernanceRepositoryConfigurationUtil {
     private static final String ZOOKEEPER_CONNECTION_STRING = "localhost:2181";
     
     public static GovernanceConfiguration getZooKeeperConfiguration(final boolean overwrite, final ShardingType shardingType) {
-        RegistryCenterConfiguration governanceCenterConfig = new RegistryCenterConfiguration("ZooKeeper", ZOOKEEPER_CONNECTION_STRING, new Properties());
+        RegistryCenterConfiguration registryCenterConfig = new RegistryCenterConfiguration("ZooKeeper", ZOOKEEPER_CONNECTION_STRING, new Properties());
         switch (shardingType) {
             case SHARDING_DATABASES_AND_TABLES:
-                return new GovernanceConfiguration("governance-sharding-data-source", governanceCenterConfig, overwrite);
+                return new GovernanceConfiguration("governance-sharding-data-source", registryCenterConfig, overwrite);
             case READWRITE_SPLITTING:
-                return new GovernanceConfiguration("governance-readwrite-splitting-data-source", governanceCenterConfig, overwrite);
+                return new GovernanceConfiguration("governance-readwrite-splitting-data-source", registryCenterConfig, overwrite);
             case ENCRYPT:
-                return new GovernanceConfiguration("governance-encrypt-data-source", governanceCenterConfig, overwrite);
+                return new GovernanceConfiguration("governance-encrypt-data-source", registryCenterConfig, overwrite);
             case SHADOW:
-                return new GovernanceConfiguration("governance-shadow-data-source", governanceCenterConfig, overwrite);
-            default:
-                throw new UnsupportedOperationException(shardingType.toString());
-        }
-    }
-    
-    public static GovernanceConfiguration getNacosConfiguration(final boolean overwrite, final ShardingType shardingType) {
-        Properties zookeeperProperties = new Properties();
-        RegistryCenterConfiguration zookeeperConfig = new RegistryCenterConfiguration("ZooKeeper", ZOOKEEPER_CONNECTION_STRING, zookeeperProperties);
-        switch (shardingType) {
-            case SHARDING_DATABASES_AND_TABLES:
-                return new GovernanceConfiguration("governance-zookeeper-sharding-data-source", zookeeperConfig, overwrite);
-            case READWRITE_SPLITTING:
-                return new GovernanceConfiguration("governance-zookeeper-readwrite-splitting-data-source", zookeeperConfig, overwrite);
-            case ENCRYPT:
-                return new GovernanceConfiguration("governance-zookeeper-encrypt-data-source", zookeeperConfig, overwrite);
-            case SHADOW:
-                return new GovernanceConfiguration("governance-zookeeper-shadow-data-source", zookeeperConfig, overwrite);
+                return new GovernanceConfiguration("governance-shadow-data-source", registryCenterConfig, overwrite);
             default:
                 throw new UnsupportedOperationException(shardingType.toString());
         }
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/facade/repository/RegistryCenterRepositoryFacade.java b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/facade/repository/RegistryCenterRepositoryFacade.java
index 94c09b1..73dec2e 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/facade/repository/RegistryCenterRepositoryFacade.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/facade/repository/RegistryCenterRepositoryFacade.java
@@ -42,10 +42,10 @@ public final class RegistryCenterRepositoryFacade implements AutoCloseable {
     }
     
     private RegistryCenterRepository createGovernanceRepository(final GovernanceConfiguration config) {
-        RegistryCenterConfiguration governanceCenterConfig = config.getRegistryCenterConfiguration();
-        Preconditions.checkNotNull(governanceCenterConfig, "Governance center configuration cannot be null.");
-        RegistryCenterRepository result = TypedSPIRegistry.getRegisteredService(RegistryCenterRepository.class, governanceCenterConfig.getType(), governanceCenterConfig.getProps());
-        result.init(config.getName(), governanceCenterConfig);
+        RegistryCenterConfiguration registryCenterConfig = config.getRegistryCenterConfiguration();
+        Preconditions.checkNotNull(registryCenterConfig, "Registry center configuration cannot be null.");
+        RegistryCenterRepository result = TypedSPIRegistry.getRegisteredService(RegistryCenterRepository.class, registryCenterConfig.getType(), registryCenterConfig.getProps());
+        result.init(config.getName(), registryCenterConfig);
         return result;
     }
     
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceConfiguration.java b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceConfiguration.java
index 4af1cc0..dea40ef 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceConfiguration.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceConfiguration.java
@@ -30,7 +30,7 @@ public final class YamlGovernanceConfiguration implements YamlConfiguration {
     
     private String name;
     
-    private YamlGovernanceCenterConfiguration registryCenter;
+    private YamlRegistryCenterConfiguration registryCenter;
     
     private boolean overwrite;
 }
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapper.java b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapper.java
index 51cb0cb..d02e1d7 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapper.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapper.java
@@ -27,19 +27,19 @@ import org.apache.shardingsphere.governance.repository.api.config.GovernanceConf
  */
 public final class GovernanceConfigurationYamlSwapper implements YamlConfigurationSwapper<YamlGovernanceConfiguration, GovernanceConfiguration> {
     
-    private final GovernanceCenterConfigurationYamlSwapper governanceCenterConfigurationSwapper = new GovernanceCenterConfigurationYamlSwapper();
+    private final RegistryCenterConfigurationYamlSwapper registryCenterConfigurationYamlSwapper = new RegistryCenterConfigurationYamlSwapper();
     
     @Override
     public YamlGovernanceConfiguration swapToYamlConfiguration(final GovernanceConfiguration data) {
         YamlGovernanceConfiguration result = new YamlGovernanceConfiguration();
         result.setName(data.getName());
-        result.setRegistryCenter(governanceCenterConfigurationSwapper.swapToYamlConfiguration(data.getRegistryCenterConfiguration()));
+        result.setRegistryCenter(registryCenterConfigurationYamlSwapper.swapToYamlConfiguration(data.getRegistryCenterConfiguration()));
         return result;
     }
     
     @Override
     public GovernanceConfiguration swapToObject(final YamlGovernanceConfiguration yamlConfig) {
-        RegistryCenterConfiguration registryCenterConfiguration = governanceCenterConfigurationSwapper.swapToObject(yamlConfig.getRegistryCenter());
+        RegistryCenterConfiguration registryCenterConfiguration = registryCenterConfigurationYamlSwapper.swapToObject(yamlConfig.getRegistryCenter());
         return new GovernanceConfiguration(yamlConfig.getName(), registryCenterConfiguration, yamlConfig.isOverwrite());
     }
 }
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceCenterConfigurationYamlSwapper.java b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapper.java
similarity index 72%
rename from shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceCenterConfigurationYamlSwapper.java
rename to shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapper.java
index b023281..6f129d2 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceCenterConfigurationYamlSwapper.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapper.java
@@ -17,18 +17,18 @@
 
 package org.apache.shardingsphere.governance.core.yaml.swapper;
 
-import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration;
+import org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.repository.api.config.RegistryCenterConfiguration;
 import org.apache.shardingsphere.infra.yaml.swapper.YamlConfigurationSwapper;
 
 /**
- * Governance center configuration YAML swapper.
+ * Registry center configuration YAML swapper.
  */
-public final class GovernanceCenterConfigurationYamlSwapper implements YamlConfigurationSwapper<YamlGovernanceCenterConfiguration, RegistryCenterConfiguration> {
+public final class RegistryCenterConfigurationYamlSwapper implements YamlConfigurationSwapper<YamlRegistryCenterConfiguration, RegistryCenterConfiguration> {
     
     @Override
-    public YamlGovernanceCenterConfiguration swapToYamlConfiguration(final RegistryCenterConfiguration config) {
-        YamlGovernanceCenterConfiguration result = new YamlGovernanceCenterConfiguration();
+    public YamlRegistryCenterConfiguration swapToYamlConfiguration(final RegistryCenterConfiguration config) {
+        YamlRegistryCenterConfiguration result = new YamlRegistryCenterConfiguration();
         result.setType(config.getType());
         result.setServerLists(config.getServerLists());
         result.setProps(config.getProps());
@@ -36,7 +36,7 @@ public final class GovernanceCenterConfigurationYamlSwapper implements YamlConfi
     }
     
     @Override
-    public RegistryCenterConfiguration swapToObject(final YamlGovernanceCenterConfiguration yamlConfig) {
+    public RegistryCenterConfiguration swapToObject(final YamlRegistryCenterConfiguration yamlConfig) {
         return new RegistryCenterConfiguration(yamlConfig.getType(), yamlConfig.getServerLists(), yamlConfig.getProps());
     }
 }
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapperTest.java b/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapperTest.java
index 02058d7..706ba98 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapperTest.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/GovernanceConfigurationYamlSwapperTest.java
@@ -17,7 +17,7 @@
 
 package org.apache.shardingsphere.governance.core.yaml.swapper;
 
-import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration;
+import org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceConfiguration;
 import org.apache.shardingsphere.governance.repository.api.config.RegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.repository.api.config.GovernanceConfiguration;
@@ -97,8 +97,8 @@ public final class GovernanceConfigurationYamlSwapperTest {
         return result;
     }
     
-    private YamlGovernanceCenterConfiguration createYamlRegistryCenterConfiguration() {
-        YamlGovernanceCenterConfiguration result = new YamlGovernanceCenterConfiguration();
+    private YamlRegistryCenterConfiguration createYamlRegistryCenterConfiguration() {
+        YamlRegistryCenterConfiguration result = new YamlRegistryCenterConfiguration();
         result.setType("TEST");
         result.setProps(new Properties());
         result.setServerLists("127.0.0.1:2181");
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapperTest.java b/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapperTest.java
index e4d8ef2..6be0c0b 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapperTest.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/test/java/org/apache/shardingsphere/governance/core/yaml/swapper/RegistryCenterConfigurationYamlSwapperTest.java
@@ -17,7 +17,7 @@
 
 package org.apache.shardingsphere.governance.core.yaml.swapper;
 
-import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration;
+import org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.repository.api.config.RegistryCenterConfiguration;
 import org.junit.Test;
 
@@ -31,7 +31,7 @@ public final class RegistryCenterConfigurationYamlSwapperTest {
     @Test
     public void assertToYamlConfiguration() {
         RegistryCenterConfiguration expected = new RegistryCenterConfiguration("TEST", "127.0.0.1:2181", new Properties());
-        YamlGovernanceCenterConfiguration actual = new GovernanceCenterConfigurationYamlSwapper().swapToYamlConfiguration(expected);
+        YamlRegistryCenterConfiguration actual = new RegistryCenterConfigurationYamlSwapper().swapToYamlConfiguration(expected);
         assertThat(actual.getType(), is(expected.getType()));
         assertThat(actual.getServerLists(), is(expected.getServerLists()));
         assertThat(actual.getProps(), is(expected.getProps()));
@@ -39,15 +39,15 @@ public final class RegistryCenterConfigurationYamlSwapperTest {
     
     @Test
     public void assertSwapToObject() {
-        YamlGovernanceCenterConfiguration yamlConfig = getYamlGovernanceCenterConfiguration();
-        RegistryCenterConfiguration governanceCenterConfig = new GovernanceCenterConfigurationYamlSwapper().swapToObject(yamlConfig);
-        assertThat(governanceCenterConfig.getType(), is(yamlConfig.getType()));
-        assertThat(governanceCenterConfig.getServerLists(), is(yamlConfig.getServerLists()));
-        assertThat(governanceCenterConfig.getProps(), is(yamlConfig.getProps()));
+        YamlRegistryCenterConfiguration yamlConfig = getYamlRegistryCenterConfiguration();
+        RegistryCenterConfiguration config = new RegistryCenterConfigurationYamlSwapper().swapToObject(yamlConfig);
+        assertThat(config.getType(), is(yamlConfig.getType()));
+        assertThat(config.getServerLists(), is(yamlConfig.getServerLists()));
+        assertThat(config.getProps(), is(yamlConfig.getProps()));
     }
     
-    private YamlGovernanceCenterConfiguration getYamlGovernanceCenterConfiguration() {
-        YamlGovernanceCenterConfiguration result = new YamlGovernanceCenterConfiguration();
+    private YamlRegistryCenterConfiguration getYamlRegistryCenterConfiguration() {
+        YamlRegistryCenterConfiguration result = new YamlRegistryCenterConfiguration();
         result.setType("TEST");
         result.setProps(new Properties());
         result.setServerLists("127.0.0.1:2181");
diff --git a/shardingsphere-governance/shardingsphere-governance-repository/shardingsphere-governance-repository-api/src/main/java/org/apache/shardingsphere/governance/repository/api/RegistryCenterRepository.java b/shardingsphere-governance/shardingsphere-governance-repository/shardingsphere-governance-repository-api/src/main/java/org/apache/shardingsphere/governance/repository/api/RegistryCenterRepository.java
index 1c82230..289c29c 100644
--- a/shardingsphere-governance/shardingsphere-governance-repository/shardingsphere-governance-repository-api/src/main/java/org/apache/shardingsphere/governance/repository/api/RegistryCenterRepository.java
+++ b/shardingsphere-governance/shardingsphere-governance-repository/shardingsphere-governance-repository-api/src/main/java/org/apache/shardingsphere/governance/repository/api/RegistryCenterRepository.java
@@ -35,15 +35,15 @@ public interface RegistryCenterRepository extends TypedSPI {
     String PATH_SEPARATOR = "/";
     
     /**
-     * Initialize governance center.
+     * Initialize registry center.
      *
-     * @param name governance center name
-     * @param config governance center configuration
+     * @param name registry center name
+     * @param config registry center configuration
      */
     void init(String name, RegistryCenterConfiguration config);
     
     /**
-     * Get data from governance center.
+     * Get data from registry center.
      *
      * <p>Maybe use cache if existed.</p>
      *
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/api/yaml/YamlGovernanceShardingSphereDataSourceFactory.java b/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/api/yaml/YamlGovernanceShardingSphereDataSourceFactory.java
index 4dd72dd..fded750 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/api/yaml/YamlGovernanceShardingSphereDataSourceFactory.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/api/yaml/YamlGovernanceShardingSphereDataSourceFactory.java
@@ -20,7 +20,7 @@ package org.apache.shardingsphere.driver.governance.api.yaml;
 import lombok.AccessLevel;
 import lombok.NoArgsConstructor;
 import org.apache.shardingsphere.driver.governance.internal.datasource.GovernanceShardingSphereDataSource;
-import org.apache.shardingsphere.driver.governance.internal.util.YamlGovernanceRepositoryConfigurationSwapperUtil;
+import org.apache.shardingsphere.driver.governance.internal.util.YamlGovernanceConfigurationSwapperUtil;
 import org.apache.shardingsphere.driver.governance.internal.yaml.YamlGovernanceRootRuleConfigurations;
 import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceConfiguration;
 import org.apache.shardingsphere.infra.config.RuleConfiguration;
@@ -109,13 +109,13 @@ public final class YamlGovernanceShardingSphereDataSourceFactory {
     }
     
     private static DataSource createDataSourceWithoutRules(final YamlGovernanceConfiguration governance) throws SQLException {
-        return new GovernanceShardingSphereDataSource(YamlGovernanceRepositoryConfigurationSwapperUtil.marshal(governance));
+        return new GovernanceShardingSphereDataSource(YamlGovernanceConfigurationSwapperUtil.marshal(governance));
     }
     
     private static DataSource createDataSourceWithRules(final Map<String, DataSource> dataSourceMap, final Collection<RuleConfiguration> ruleConfigurations,
                                                         final Properties props, final YamlGovernanceConfiguration governance) throws SQLException {
         return new GovernanceShardingSphereDataSource(dataSourceMap, ruleConfigurations, props, 
-                YamlGovernanceRepositoryConfigurationSwapperUtil.marshal(governance));
+                YamlGovernanceConfigurationSwapperUtil.marshal(governance));
     }
     
     private static YamlGovernanceRootRuleConfigurations unmarshal(final File yamlFile) throws IOException {
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceRepositoryConfigurationSwapperUtil.java b/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceConfigurationSwapperUtil.java
similarity index 77%
rename from shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceRepositoryConfigurationSwapperUtil.java
rename to shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceConfigurationSwapperUtil.java
index c0a9932..0d33245 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceRepositoryConfigurationSwapperUtil.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/main/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceConfigurationSwapperUtil.java
@@ -21,21 +21,21 @@ import lombok.AccessLevel;
 import lombok.NoArgsConstructor;
 import org.apache.shardingsphere.governance.repository.api.config.GovernanceConfiguration;
 import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceConfiguration;
-import org.apache.shardingsphere.governance.core.yaml.swapper.GovernanceCenterConfigurationYamlSwapper;
+import org.apache.shardingsphere.governance.core.yaml.swapper.RegistryCenterConfigurationYamlSwapper;
 
 /**
  * YAML governance configuration swapper utility.
  */
 @NoArgsConstructor(access = AccessLevel.PRIVATE)
-public final class YamlGovernanceRepositoryConfigurationSwapperUtil {
+public final class YamlGovernanceConfigurationSwapperUtil {
     
-    private static final GovernanceCenterConfigurationYamlSwapper SWAPPER = new GovernanceCenterConfigurationYamlSwapper();
+    private static final RegistryCenterConfigurationYamlSwapper SWAPPER = new RegistryCenterConfigurationYamlSwapper();
     
     /**
-     * Marshal YAML governance repository configuration map to instance configuration map.
+     * Marshal YAML governance configuration to governance configuration.
      *
      * @param governance YAML governance configuration
-     * @return governance repository configuration map
+     * @return governance configuration
      */
     public static GovernanceConfiguration marshal(final YamlGovernanceConfiguration governance) {
         return new GovernanceConfiguration(governance.getName(), SWAPPER.swapToObject(governance.getRegistryCenter()), governance.isOverwrite());
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/test/java/org/apache/shardingsphere/driver/governance/internal/util/YamlInstanceConfigurationSwapperUtilTest.java b/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/test/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceConfigurationSwapperUtilTest.java
similarity index 80%
rename from shardingsphere-jdbc/shardingsphere-jdbc-governance/src/test/java/org/apache/shardingsphere/driver/governance/internal/util/YamlInstanceConfigurationSwapperUtilTest.java
rename to shardingsphere-jdbc/shardingsphere-jdbc-governance/src/test/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceConfigurationSwapperUtilTest.java
index 4fc21d4..3dc48ed 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/test/java/org/apache/shardingsphere/driver/governance/internal/util/YamlInstanceConfigurationSwapperUtilTest.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-governance/src/test/java/org/apache/shardingsphere/driver/governance/internal/util/YamlGovernanceConfigurationSwapperUtilTest.java
@@ -18,7 +18,7 @@
 package org.apache.shardingsphere.driver.governance.internal.util;
 
 import org.apache.shardingsphere.governance.repository.api.config.RegistryCenterConfiguration;
-import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration;
+import org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceConfiguration;
 import org.junit.Test;
 
@@ -27,12 +27,12 @@ import java.util.Properties;
 import static org.hamcrest.CoreMatchers.is;
 import static org.junit.Assert.assertThat;
 
-public final class YamlInstanceConfigurationSwapperUtilTest {
+public final class YamlGovernanceConfigurationSwapperUtilTest {
     
     @Test
     public void marshal() {
         YamlGovernanceConfiguration expected = createExpectedYamlGovernanceConfiguration();
-        RegistryCenterConfiguration actual = YamlGovernanceRepositoryConfigurationSwapperUtil.marshal(expected).getRegistryCenterConfiguration();
+        RegistryCenterConfiguration actual = YamlGovernanceConfigurationSwapperUtil.marshal(expected).getRegistryCenterConfiguration();
         assertThat(actual.getType(), is(expected.getRegistryCenter().getType()));
         assertThat(actual.getServerLists(), is(expected.getRegistryCenter().getServerLists()));
         assertThat(actual.getProps(), is(expected.getRegistryCenter().getProps()));
@@ -41,12 +41,12 @@ public final class YamlInstanceConfigurationSwapperUtilTest {
     private YamlGovernanceConfiguration createExpectedYamlGovernanceConfiguration() {
         YamlGovernanceConfiguration result = new YamlGovernanceConfiguration();
         result.setName("test");
-        result.setRegistryCenter(createYamlGovernanceRepositoryConfiguration());
+        result.setRegistryCenter(createYamlRegistryRepositoryConfiguration());
         return result;
     }
     
-    private YamlGovernanceCenterConfiguration createYamlGovernanceRepositoryConfiguration() {
-        YamlGovernanceCenterConfiguration result = new YamlGovernanceCenterConfiguration();
+    private YamlRegistryCenterConfiguration createYamlRegistryRepositoryConfiguration() {
+        YamlRegistryCenterConfiguration result = new YamlRegistryCenterConfiguration();
         result.setType("ZooKeeper");
         result.setServerLists("localhost:2181");
         result.setProps(new Properties());
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/java/org/apache/shardingsphere/spring/boot/governance/ShardingSphereGovernanceAutoConfiguration.java b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/java/org/apache/shardingsphere/spring/boot/governance/ShardingSphereGovernanceAutoConfi [...]
index 3e8c280..9791804 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/java/org/apache/shardingsphere/spring/boot/governance/ShardingSphereGovernanceAutoConfiguration.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/java/org/apache/shardingsphere/spring/boot/governance/ShardingSphereGovernanceAutoConfiguration.java
@@ -21,7 +21,7 @@ import com.google.common.base.Preconditions;
 import lombok.RequiredArgsConstructor;
 import org.apache.shardingsphere.driver.governance.internal.datasource.GovernanceShardingSphereDataSource;
 import org.apache.shardingsphere.infra.config.RuleConfiguration;
-import org.apache.shardingsphere.governance.core.yaml.swapper.GovernanceCenterConfigurationYamlSwapper;
+import org.apache.shardingsphere.governance.core.yaml.swapper.RegistryCenterConfigurationYamlSwapper;
 import org.apache.shardingsphere.governance.repository.api.config.GovernanceConfiguration;
 import org.apache.shardingsphere.spring.boot.datasource.DataSourceMapSetter;
 import org.apache.shardingsphere.spring.boot.governance.common.GovernanceSpringBootRootConfiguration;
@@ -64,7 +64,7 @@ public class ShardingSphereGovernanceAutoConfiguration implements EnvironmentAwa
     
     private final GovernanceSpringBootRootConfiguration root;
     
-    private final GovernanceCenterConfigurationYamlSwapper swapper = new GovernanceCenterConfigurationYamlSwapper();
+    private final RegistryCenterConfigurationYamlSwapper swapper = new RegistryCenterConfigurationYamlSwapper();
     
     /**
      * Get governance configuration.
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json
index 093145c..348b355 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-boot-starter/src/main/resources/META-INF/additional-spring-configuration-metadata.json
@@ -15,7 +15,6 @@
  * limitations under the License.
  */
 
-
 {
   "groups": [
     {
@@ -78,7 +77,7 @@
     },
     {
       "name": "spring.shardingsphere.governance",
-      "type": "java.util.Map<java.lang.String,org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration>",
+      "type": "java.util.Map<java.lang.String,org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration>",
       "sourceType": "org.apache.shardingsphere.spring.boot.governance.common.GovernanceSpringBootRootConfiguration",
       "description": "Customize ShardingSphere governance instance."
     },
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/handler/GovernanceNamespaceHandler.java b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/handler/GovernanceNamespaceHandler.java
index 5756ecd..f89c059 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/handler/GovernanceNamespaceHandler.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/handler/GovernanceNamespaceHandler.java
@@ -18,9 +18,9 @@
 package org.apache.shardingsphere.spring.namespace.governance.handler;
 
 import org.apache.shardingsphere.spring.namespace.governance.constants.DataSourceBeanDefinitionTag;
-import org.apache.shardingsphere.spring.namespace.governance.constants.GovernanceCenterConfigurationBeanDefinitionTag;
+import org.apache.shardingsphere.spring.namespace.governance.constants.RegistryCenterConfigurationBeanDefinitionTag;
 import org.apache.shardingsphere.spring.namespace.governance.parser.DataSourceBeanDefinitionParser;
-import org.apache.shardingsphere.spring.namespace.governance.parser.GovernanceCenterConfigurationBeanDefinitionParser;
+import org.apache.shardingsphere.spring.namespace.governance.parser.RegistryCenterConfigurationBeanDefinitionParser;
 import org.springframework.beans.factory.xml.NamespaceHandlerSupport;
 
 /**
@@ -30,7 +30,7 @@ public final class GovernanceNamespaceHandler extends NamespaceHandlerSupport {
     
     @Override
     public void init() {
-        registerBeanDefinitionParser(GovernanceCenterConfigurationBeanDefinitionTag.REG_CENTER_ROOT_TAG, new GovernanceCenterConfigurationBeanDefinitionParser());
+        registerBeanDefinitionParser(RegistryCenterConfigurationBeanDefinitionTag.REG_CENTER_ROOT_TAG, new RegistryCenterConfigurationBeanDefinitionParser());
         registerBeanDefinitionParser(DataSourceBeanDefinitionTag.ROOT_TAG, new DataSourceBeanDefinitionParser());
     }
 }
diff --git a/shardingsphere-proxy/shardingsphere-proxy-common/src/test/java/org/apache/shardingsphere/proxy/config/yaml/swapper/YamlProxyConfigurationSwapperTest.java b/shardingsphere-proxy/shardingsphere-proxy-common/src/test/java/org/apache/shardingsphere/proxy/config/yaml/swapper/YamlProxyConfigurationSwapperTest.java
index 134bc20..72717ee 100644
--- a/shardingsphere-proxy/shardingsphere-proxy-common/src/test/java/org/apache/shardingsphere/proxy/config/yaml/swapper/YamlProxyConfigurationSwapperTest.java
+++ b/shardingsphere-proxy/shardingsphere-proxy-common/src/test/java/org/apache/shardingsphere/proxy/config/yaml/swapper/YamlProxyConfigurationSwapperTest.java
@@ -20,7 +20,7 @@ package org.apache.shardingsphere.proxy.config.yaml.swapper;
 import com.google.common.collect.Lists;
 import org.apache.shardingsphere.authority.api.config.AuthorityRuleConfiguration;
 import org.apache.shardingsphere.authority.yaml.config.YamlAuthorityRuleConfiguration;
-import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration;
+import org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceConfiguration;
 import org.apache.shardingsphere.infra.config.RuleConfiguration;
 import org.apache.shardingsphere.infra.config.datasource.DataSourceParameter;
@@ -137,7 +137,7 @@ public final class YamlProxyConfigurationSwapperTest {
     }
     
     private void prepareRegistryCenter(final YamlGovernanceConfiguration yamlGovernanceConfig) {
-        YamlGovernanceCenterConfiguration registryCenterConfig = mock(YamlGovernanceCenterConfiguration.class);
+        YamlRegistryCenterConfiguration registryCenterConfig = mock(YamlRegistryCenterConfiguration.class);
         when(yamlGovernanceConfig.getRegistryCenter()).thenReturn(registryCenterConfig);
         when(registryCenterConfig.getType()).thenReturn("typeOne");
         when(registryCenterConfig.getServerLists()).thenReturn("serverLists1");
diff --git a/shardingsphere-scaling/shardingsphere-scaling-core/src/test/java/org/apache/shardingsphere/scaling/core/config/yaml/ServerConfigurationYamlSwapperTest.java b/shardingsphere-scaling/shardingsphere-scaling-core/src/test/java/org/apache/shardingsphere/scaling/core/config/yaml/ServerConfigurationYamlSwapperTest.java
index 9997300..eacf133 100644
--- a/shardingsphere-scaling/shardingsphere-scaling-core/src/test/java/org/apache/shardingsphere/scaling/core/config/yaml/ServerConfigurationYamlSwapperTest.java
+++ b/shardingsphere-scaling/shardingsphere-scaling-core/src/test/java/org/apache/shardingsphere/scaling/core/config/yaml/ServerConfigurationYamlSwapperTest.java
@@ -17,7 +17,7 @@
 
 package org.apache.shardingsphere.scaling.core.config.yaml;
 
-import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceCenterConfiguration;
+import org.apache.shardingsphere.governance.core.yaml.config.YamlRegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.core.yaml.config.YamlGovernanceConfiguration;
 import org.apache.shardingsphere.governance.repository.api.config.RegistryCenterConfiguration;
 import org.apache.shardingsphere.governance.repository.api.config.GovernanceConfiguration;
@@ -55,10 +55,10 @@ public final class ServerConfigurationYamlSwapperTest {
     
     private YamlServerConfiguration mockYamlServerConfig() {
         YamlServerConfiguration result = new YamlServerConfiguration();
-        YamlGovernanceConfiguration governance = new YamlGovernanceConfiguration();
-        governance.setName("test");
-        governance.setRegistryCenter(new YamlGovernanceCenterConfiguration());
-        result.setGovernance(governance);
+        YamlGovernanceConfiguration config = new YamlGovernanceConfiguration();
+        config.setName("test");
+        config.setRegistryCenter(new YamlRegistryCenterConfiguration());
+        result.setGovernance(config);
         result.getScaling().setWorkerThread(10);
         return result;
     }
diff --git a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceCenterConfiguration.java b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlRegistryCenterConfiguration.java
similarity index 89%
rename from shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceCenterConfiguration.java
rename to shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlRegistryCenterConfiguration.java
index 8a10162..0547503 100644
--- a/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlGovernanceCenterConfiguration.java
+++ b/shardingsphere-governance/shardingsphere-governance-core/src/main/java/org/apache/shardingsphere/governance/core/yaml/config/YamlRegistryCenterConfiguration.java
@@ -24,11 +24,11 @@ import org.apache.shardingsphere.infra.yaml.config.YamlConfiguration;
 import java.util.Properties;
 
 /**
  * Governance center configuration for YAML.
  */
 @Getter
 @Setter
-public final class YamlGovernanceCenterConfiguration implements YamlConfiguration {
+public final class YamlRegistryCenterConfiguration implements YamlConfiguration {
     
     private String type;
     
@@ -24,11 +24,11 @@ import org.apache.shardingsphere.infra.yaml.config.YamlConfiguration;
 
 /**
- * Governance center configuration for YAML.
+ * Registry center configuration for YAML.
  */
 @Getter
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/constants/GovernanceCenterConfigurationBeanDefinitionTag.java b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/constants/Regi [...]
similarity index 91%
rename from shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/constants/GovernanceCenterConfigurationBeanDefinitionTag.java
rename to shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/constants/RegistryCenterConfigurationBeanDefinitionTag.java
index 6e1b447..815af42 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/constants/GovernanceCenterConfigurationBeanDefinitionTag.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/constants/RegistryCenterConfigurationBeanDefinitionTag.java
@@ -21,10 +21,10 @@ import lombok.AccessLevel;
 import lombok.NoArgsConstructor;
 
 /**
  * Governance center configuration bean definition tag.
  */
 @NoArgsConstructor(access = AccessLevel.PRIVATE)
-public final class GovernanceCenterConfigurationBeanDefinitionTag {
+public final class RegistryCenterConfigurationBeanDefinitionTag {
     
     public static final String REG_CENTER_ROOT_TAG = "reg-center";
     
@@ -21,10 +21,10 @@ import lombok.AccessLevel;
 
 /**
- * Governance center configuration bean definition tag.
+ * Registry center configuration bean definition tag.
  */
 @NoArgsConstructor(access = AccessLevel.PRIVATE)
diff --git a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/parser/GovernanceCenterConfigurationBeanDefinitionParser.java b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/parser/Registr [...]
similarity index 79%
rename from shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/parser/GovernanceCenterConfigurationBeanDefinitionParser.java
rename to shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/parser/RegistryCenterConfigurationBeanDefinitionParser.java
index ee63f46..9fad0d8 100644
--- a/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/parser/GovernanceCenterConfigurationBeanDefinitionParser.java
+++ b/shardingsphere-jdbc/shardingsphere-jdbc-spring/shardingsphere-jdbc-governance-spring/shardingsphere-jdbc-governance-spring-namespace/src/main/java/org/apache/shardingsphere/spring/namespace/governance/parser/RegistryCenterConfigurationBeanDefinitionParser.java
@@ -18,7 +18,7 @@
 package org.apache.shardingsphere.spring.namespace.governance.parser;
 
 import org.apache.shardingsphere.governance.repository.api.config.RegistryCenterConfiguration;
-import org.apache.shardingsphere.spring.namespace.governance.constants.GovernanceCenterConfigurationBeanDefinitionTag;
+import org.apache.shardingsphere.spring.namespace.governance.constants.RegistryCenterConfigurationBeanDefinitionTag;
 import org.springframework.beans.factory.support.AbstractBeanDefinition;
 import org.springframework.beans.factory.support.BeanDefinitionBuilder;
 import org.springframework.beans.factory.xml.AbstractBeanDefinitionParser;
@@ -29,21 +29,21 @@ import org.w3c.dom.Element;
 import java.util.Properties;
 
 /**
  * Governance center configuration parser for spring namespace.
  */
-public final class GovernanceCenterConfigurationBeanDefinitionParser extends AbstractBeanDefinitionParser {
+public final class RegistryCenterConfigurationBeanDefinitionParser extends AbstractBeanDefinitionParser {
     
     @Override
     protected AbstractBeanDefinition parseInternal(final Element element, final ParserContext parserContext) {
         BeanDefinitionBuilder factory = BeanDefinitionBuilder.rootBeanDefinition(RegistryCenterConfiguration.class);
-        factory.addConstructorArgValue(element.getAttribute(GovernanceCenterConfigurationBeanDefinitionTag.TYPE_ATTRIBUTE));
-        factory.addConstructorArgValue(element.getAttribute(GovernanceCenterConfigurationBeanDefinitionTag.SERVER_LISTS_ATTRIBUTE));
+        factory.addConstructorArgValue(element.getAttribute(RegistryCenterConfigurationBeanDefinitionTag.TYPE_ATTRIBUTE));
+        factory.addConstructorArgValue(element.getAttribute(RegistryCenterConfigurationBeanDefinitionTag.SERVER_LISTS_ATTRIBUTE));
         factory.addConstructorArgValue(parseProperties(element, parserContext));
         return factory.getBeanDefinition();
     }
     
     private Properties parseProperties(final Element element, final ParserContext parserContext) {
-        Element propsElement = DomUtils.getChildElementByTagName(element, GovernanceCenterConfigurationBeanDefinitionTag.PROP_TAG);
+        Element propsElement = DomUtils.getChildElementByTagName(element, RegistryCenterConfigurationBeanDefinitionTag.PROP_TAG);
         return null == propsElement ? new Properties() : parserContext.getDelegate().parsePropsElement(propsElement);
     }
 }
@@ -29,21 +29,21 @@ import org.w3c.dom.Element;
 
 /**
- * Governance center configuration parser for spring namespace.
+ * Registry center configuration parser for spring namespace.
  */